@@ -8,6 +8,8 @@
 #ifndef _UAPI_FSL_MC_H_
 #define _UAPI_FSL_MC_H_
 
+#include <linux/types.h>
+
 #define MC_CMD_NUM_OF_PARAMS	7
 
 /**
@@ -15,17 +17,18 @@
  * @header: MC command header
  * @params: MC command parameters
  *
- * Used by RESTOOL_SEND_MC_COMMAND
+ * Used by FSL_MC_SEND_MC_COMMAND
  */
 struct fsl_mc_command {
-	__u64 header;
-	__u64 params[MC_CMD_NUM_OF_PARAMS];
+	__le64 header;
+	__le64 params[MC_CMD_NUM_OF_PARAMS];
 };
 
-#define RESTOOL_IOCTL_TYPE	'R'
-#define RESTOOL_IOCTL_SEQ	0xE0
+#define FSL_MC_SEND_CMD_IOCTL_TYPE	'R'
+#define FSL_MC_SEND_CMD_IOCTL_SEQ	0xE0
 
-#define RESTOOL_SEND_MC_COMMAND \
-	_IOWR(RESTOOL_IOCTL_TYPE, RESTOOL_IOCTL_SEQ, struct fsl_mc_command)
+#define FSL_MC_SEND_MC_COMMAND \
+	_IOWR(FSL_MC_SEND_CMD_IOCTL_TYPE, FSL_MC_SEND_CMD_IOCTL_SEQ, \
+	struct fsl_mc_command)
 
 #endif /* _UAPI_FSL_MC_H_ */
